import os
from nose.tools import raises
from tests import utils


DATA_DIR = os.path.join(os.path.dirname(__file__), 'data', 'bad')
reference_mdm_file = os.path.join(DATA_DIR, 'reference.MDM')


def compare_to_reference_mdm(test_mdm_file):
    utils.default_mdm_compare(
        os.path.join(DATA_DIR, test_mdm_file),
        reference_mdm_file
    )

@raises(IOError)
def test_missing_file():
    compare_to_reference_mdm('nonexistent.MDM')

@raises(ValueError)
def test_missing_a_line():
    compare_to_reference_mdm('missing-a-line.MDM')

@raises(ValueError)
def test_different_results():
    compare_to_reference_mdm('different-results.MDM')



import numpy as np


__version__ = '1.0.5'
DEFAULT_PRECISION = 7


def mdm_compare(mdm_file1, mdm_file2, decimal_precision=DEFAULT_PRECISION):
    with open(mdm_file1, 'r') as f1:
        lines1 = f1.readlines()
        with open(mdm_file2, 'r') as f2:
            lines2 = f2.readlines()

            if len(lines1) != len(lines2):
                raise ValueError('Files do not have the same number of lines')

            for idx, (line1, line2) in enumerate(zip(lines1, lines2)):
                if line1 != line2:
                    array1 = np.fromstring(line1, dtype=float, sep=' ')
                    array2 = np.fromstring(line2, dtype=float, sep=' ')
                    try:
                        np.testing.assert_almost_equal(
                            array1,
                            array2,
                            decimal=decimal_precision,
                        )
                    except AssertionError:
                        raise ValueError("Files are different on line %d" % (idx+1))
    return True

def main(): #pragma: no cover
    import argparse
    import sys

    parser = argparse.ArgumentParser(
        description='Compare 2 experiment results stored in the MDM file format'
    )
    parser.add_argument(
        'file',
        nargs=2,
        help='Experiment result stored in the MDM file format'
    )
    parser.add_argument(
        '-p',
        '--precision',
        default=DEFAULT_PRECISION,
        type=int,
        help="Decimal precision (at %d decimals by default) required to " \
             "consider MDM files the same" % DEFAULT_PRECISION
    )
    parser.add_argument(
        '--version',
        action='version',
        version="%(prog)s " + __version__
    )
    args = parser.parse_args()


    try:
        mdm_compare(*args.file, decimal_precision=args.precision)
        print 'Files can be considered the same'
    except Exception, e:
        print >> sys.stderr, "ERROR:", e
        sys.exit(1)

if __name__ == '__main__':
    main()



import os
from tests import utils


TEST_CASES = {}
def setup():
    data_dir = os.path.join(os.path.dirname(__file__), 'data', 'good')
    for directory_name in utils.list_subdirs_in_dir(data_dir):
        TEST_CASES[directory_name] = utils.list_files_in_dir(
            os.path.join(data_dir, directory_name)
        ) 

def test_preconditions():
    for directory_name in TEST_CASES:
            yield check_preconditions, directory_name

def check_preconditions(directory_name):
    num_files = len(TEST_CASES[directory_name])
    assert num_files == 2, "Found %d file(s), expected 2" % num_files

def test_sanity():
    for directory_name in TEST_CASES:
        yield check_sanity, directory_name

def check_sanity(directory_name):
    for file_name in TEST_CASES[directory_name]:
        assert utils.default_mdm_compare(file_name, file_name)

def test_different_platforms():
    for directory_name in TEST_CASES:
        yield check_different_platforms, directory_name

def check_different_platforms(directory_name):
    assert utils.default_mdm_compare(*TEST_CASES[directory_name])



import sys
from setuptools import setup


if sys.version_info < (2, 6):
    print 'ERROR: mdm_compare requires at least Python 2.6 to run.'
    sys.exit(1)


setup(
    name='mdm_compare',
    version='1.0.5',
    url='https://bitbucket.org/petar/mdm_compare',
    download_url='https://bitbucket.org/petar/mdm_compare',
    license='BSD',
    author='Petar Maric',
    author_email='petarmaric@uns.ac.rs',
    description='Console app and Python API for comparing 2 experiment results '\
                'stored in the MDM file format.',
    long_description=open('README').read(),
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Physics',
    ],
    platforms='any',
    py_modules=['mdm_compare'],
    entry_points={
        'console_scripts': ['mdm_compare=mdm_compare:main']
    },
    install_requires=open('requirements.txt').read().splitlines()
)
